cosmpy.protos.cosmos.tx.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.tx.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.tx.v1beta1.service_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.tx.v1beta1.service_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.tx.v1beta1.service_pb2_grpc.Service

  Bases: `object`

  Service defines a gRPC service for interacting with transactions.

  static BroadcastTx(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static GetTx(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static GetTxsEvent(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Simulate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.tx.v1beta1.service_pb2_grpc.ServiceServicer

  Bases: `object`

  Service defines a gRPC service for interacting with transactions.

  BroadcastTx(request, context)

    BroadcastTx broadcast transaction.

  GetTx(request, context)

    GetTx fetches a tx by hash.

  GetTxsEvent(request, context)

    GetTxsEvent fetches txs by event.

  Simulate(request, context)

    Simulate simulates executing a transaction for estimating gas usage.

class cosmpy.protos.cosmos.tx.v1beta1.service_pb2_grpc.ServiceStub(channel)

  Bases: `object`

  Service defines a gRPC service for interacting with transactions.

cosmpy.protos.cosmos.tx.v1beta1.service_pb2_grpc.add_ServiceServicer_to_server(servicer, server)

## cosmpy.protos.cosmos.tx.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.tx.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## Module contents